BeaconInfo

Struct BeaconInfo 

pub struct BeaconInfo {
    pub address: Option<MacAddress>,
    pub identity: Option<Identity>,
    pub rssi: Option<i8>,
    pub lqi: Option<u8>,
    /* private fields */
}

Fields

address: Option<MacAddress>

The MAC address associated with this beacon.

identity: Option<Identity>

The identity of the network being advertised by this beacon.

rssi: Option<i8>

RSSI of the beacon, measured in dBm.

A value of -128 should be treated as if this field was absent.

lqi: Option<u8>

Link Quality Index (LQI) of the beacon.

  • A value of 0 should be treated as if this field was absent.
  • A value of 1 indicates the worst possible quality where the decoded beacon is still valid.
  • A value of 255 indicates the best possible quality that can be recognized by the radio hardware.
  • Values 2-254 are intended to represent relative quality levels evenly distributed between the worst and best, with lower values always indicating a worse quality than higher values.