pub struct BufferInfo {
pub msg_total_buffers: Option<u16>,
pub msg_free_buffers: Option<u16>,
pub msg_max_used_buffers: Option<u16>,
pub msg_6lo_send_queue: Option<MessageQueueInfo>,
pub msg_6lo_reassembly_queue: Option<MessageQueueInfo>,
pub msg_ip6_queue: Option<MessageQueueInfo>,
pub msg_mpl_queue: Option<MessageQueueInfo>,
pub msg_mle_queue: Option<MessageQueueInfo>,
pub msg_coap_queue: Option<MessageQueueInfo>,
pub msg_coap_secure_queue: Option<MessageQueueInfo>,
pub msg_application_coap_queue: Option<MessageQueueInfo>,
/* private fields */
}Expand description
Message pool related info.
Fields
msg_total_buffers: Option<u16>The total number of buffers in the message pool.
msg_free_buffers: Option<u16>The number of free buffers in the message pool.
msg_max_used_buffers: Option<u16>The maximum number of used buffers at the same time.
msg_6lo_send_queue: Option<MessageQueueInfo>Info about 6LoWPAN send queue.
msg_6lo_reassembly_queue: Option<MessageQueueInfo>Info about 6LoWPAN reassembly queue.
msg_ip6_queue: Option<MessageQueueInfo>Info about IPv6 send queue.
msg_mpl_queue: Option<MessageQueueInfo>Info about MPL send queue.
msg_mle_queue: Option<MessageQueueInfo>Info about MLE delayed message queue.
msg_coap_queue: Option<MessageQueueInfo>Info about CoAP/TMF send queue.
msg_coap_secure_queue: Option<MessageQueueInfo>Info about CoAP secure send queue.
msg_application_coap_queue: Option<MessageQueueInfo>Info about application CoAP send queue.