ChannelInfo

Struct ChannelInfo 

pub struct ChannelInfo {
    pub index: Option<u16>,
    pub id: Option<String>,
    pub max_transmit_power_dbm: Option<i8>,
    pub spectrum_center_frequency_hz: Option<u64>,
    pub spectrum_bandwidth_hz: Option<u64>,
    pub masked_by_regulatory_domain: Option<bool>,
    /* private fields */
}

Fields

index: Option<u16>

The index used by the interface to identify this channel.

id: Option<String>

Human-readable identifier for channel.

For most network types, this is just the string representation of the index. However, some network types might have non-integer ways of identifying specific channels. This field allows the application to display the name of the channel correctly under such circumstances.

The allowed characters include:

  • Dash (-), Underscore (_), Plus(+), Semicolon(:)
  • Numbers (0-9)
  • Letters (a-z, A-Z)
max_transmit_power_dbm: Option<i8>

The maximum transmit power allowed on this channel, in dBm.

spectrum_center_frequency_hz: Option<u64>

The center RF frequency of this channel, in Hz.

For example, 802.15.4 has the following values:

ChannelCenter Frequency (Hz)
112,405,000,000
122,410,000,000
132,415,000,000
142,420,000,000
152,425,000,000
162,430,000,000
172,435,000,000
182,440,000,000
192,445,000,000
202,450,000,000
212,455,000,000
222,460,000,000
232,465,000,000
242,470,000,000
252,475,000,000
262,480,000,000
spectrum_bandwidth_hz: Option<u64>

The RF spectrum bandwidth used by this channel where the power level is expected to be higher than -20dBr, in Hz.

For example, 802.15.4 channels 11 thru 26 would have the value 2,000,000 (2 MHz).

masked_by_regulatory_domain: Option<bool>

Indicates if this channel is masked by the current regulatory domain and is thus unable to be used.