pub struct CslInfo {
pub csl_accuracy: Option<u8>,
pub csl_uncertainty: Option<u8>,
/* private fields */
}Expand description
CSL related info.
Fields
csl_accuracy: Option<u8>CSL Accuracy value of the neighbor in units of PPM.
csl_uncertainty: Option<u8>CSL Uncertainty value of the neighbor in units of 10 microseconds.