MessageQueueInfo

Struct MessageQueueInfo 

pub struct MessageQueueInfo {
    pub num_messages: Option<u16>,
    pub num_buffers: Option<u16>,
    pub total_bytes: Option<u32>,
    /* private fields */
}
Message queue related info.

Fields

num_messages: Option<u16>

Number of messages in the queue.

num_buffers: Option<u16>

Number of buffers used by all messages in the queue.

total_bytes: Option<u32>

Total number of bytes of all messages in the queue.