Telemetry

Struct Telemetry 

pub struct Telemetry {
Show 44 fields pub rssi: Option<i8>, pub tx_power: Option<i8>, pub channel_index: Option<u16>, pub partition_id: Option<u32>, pub stack_version: Option<String>, pub rcp_version: Option<String>, pub thread_link_mode: Option<u8>, pub thread_router_id: Option<u8>, pub thread_rloc: Option<u16>, pub thread_network_data_version: Option<u8>, pub thread_stable_network_data_version: Option<u8>, pub thread_network_data: Option<Vec<u8>>, pub thread_stable_network_data: Option<Vec<u8>>, pub thread_border_routing_counters: Option<BorderRoutingCounters>, pub srp_server_info: Option<SrpServerInfo>, pub dnssd_counters: Option<DnssdCounters>, pub leader_data: Option<LeaderData>, pub uptime: Option<i64>, pub nat64_info: Option<Nat64Info>, pub trel_counters: Option<TrelCounters>, pub trel_peers_info: Option<TrelPeersInfo>, pub upstream_dns_info: Option<UpstreamDnsInfo>, pub dhcp6pd_info: Option<Dhcp6PdInfo>, pub link_metrics_entries: Option<Vec<LinkMetricsEntry>>, pub border_agent_counters: Option<BorderAgentCounters>, pub multi_ail_detected: Option<bool>, pub extended_pan_id: Option<u64>, pub border_routing_peers: Option<Vec<BorderRoutingPeer>>, pub border_routing_routers: Option<Vec<BorderRoutingRouter>>, pub active_dataset: Option<OperationalDataset>, pub multiradio_neighbor_info: Option<Vec<MultiRadioNeighborInfo>>, pub router_info: Option<Vec<RouterInfo>>, pub network_data: Option<NetworkData>, pub history_report: Option<ThreadHistoryReport>, pub ipaddrs: Option<Vec<NetifAddress>>, pub ipmaddrs: Option<Vec<Ipv6Address>>, pub border_routing_prefixes: Option<Vec<BorderRoutingPrefixTable>>, pub border_routing_rdnsses: Option<Vec<BorderRoutingRdnss>>, pub netstat: Option<Vec<UdpSocket>>, pub eid_cache_entries: Option<Vec<EidCacheEntry>>, pub cca_threshold: Option<i8>, pub csl_info: Option<CslInfo>, pub buffer_info: Option<BufferInfo>, pub mle_counters: Option<MleCounters>, /* private fields */
}
LoWPAN Interface Telemetry Information.

The fields in this table are used for providing low-level telemetry and information about the LoWPAN interface for debugging and statistics purposes.

All fields are optional.

Fields

rssi: Option<i8>

The current RSSI of the radio.

tx_power: Option<i8>

The configured transmit power of the radio.

channel_index: Option<u16>

The current channel index of the radio.

partition_id: Option<u32>

The partition ID of the currently associated network partition.

stack_version: Option<String>

The version string describing the underlying mesh stack.

rcp_version: Option<String>

The version string describing the underlying radio control firmware.

thread_link_mode: Option<u8>

Thread link mode byte.

Only present on Thread networks.

Defined by section 4.5.2 of the Thread 1.1.1 specification (“Mode TLV”).

thread_router_id: Option<u8>

The router ID of this device in the currently associated network.

Only present on Thread networks.

thread_rloc: Option<u16>

The current RLOC16 address of this node.

Only present on Thread networks.

thread_network_data_version: Option<u8>

The full network data version.

Only present on Thread networks.

thread_stable_network_data_version: Option<u8>

The stable network data version.

Only present on Thread networks.

thread_network_data: Option<Vec<u8>>

The current Thread network data, in raw binary form, as defined in section 5.13 of the Thread 1.1.1 specification.

Only present on Thread networks.

thread_stable_network_data: Option<Vec<u8>>

The current Thread stable network data, in raw binary form, as defined in section 5.13 of the Thread 1.1.1 specification.

Only present on Thread networks.

thread_border_routing_counters: Option<BorderRoutingCounters>

The counters associated with border routing messages.

Only present on Thread networks.

srp_server_info: Option<SrpServerInfo>

The SRP server information.

Only present on Thread networks.

dnssd_counters: Option<DnssdCounters>

The DNS-SD server counters.

Only present on Thread networks.

leader_data: Option<LeaderData>

The data associated with the leader of the currently associated Thread network.

Only present on Thread networks.

uptime: Option<i64>

The uptime of the current instance.

Required.

nat64_info: Option<Nat64Info>

Information about the NAT64

Only present on Thread networks.

trel_counters: Option<TrelCounters>

Information about the TREL interface, if available.

Only present on Thread networks.

trel_peers_info: Option<TrelPeersInfo>

Information about the TREL peers, if available.

Only present on Thread networks.

upstream_dns_info: Option<UpstreamDnsInfo>

Information about the Upstream DNS feature, if available.

Only present on Thread networks.

dhcp6pd_info: Option<Dhcp6PdInfo>

Information about the DHCPv6 PD feature, if available.

Only present on Thread networks.

link_metrics_entries: Option<Vec<LinkMetricsEntry>>

Link Metrics Manager related info, if available.

Only present on Thread networks.

border_agent_counters: Option<BorderAgentCounters>

Counters related to border agent functionality.

Only present on Thread networks.

multi_ail_detected: Option<bool>

Whether multi-AIL (Adjacent Infrastructure Link) scenario is detected.

Only present on Thread networks.

extended_pan_id: Option<u64>

The Extended PAN ID of the currently associated Thread network. This 8-byte unique identifier is used to distinguish different Thread networks.

Only present on Thread networks.

border_routing_peers: Option<Vec<BorderRoutingPeer>>

Thread Border Routing peers information.

Only present on Thread networks.

border_routing_routers: Option<Vec<BorderRoutingRouter>>

Thread Border Routing discovered routers by Border Routing Manager on the infrastructure link.

Only present on Thread networks.

active_dataset: Option<OperationalDataset>

Thread Active Operational Dataset.

Only present on Thread networks.

multiradio_neighbor_info: Option<Vec<MultiRadioNeighborInfo>>

The multi radio link information associated with a neighbor with a given Extended Address.

Only present on Thread networks.

router_info: Option<Vec<RouterInfo>>

Information regarding all active routers within the Thread network.

Only present on Thread networks.

network_data: Option<NetworkData>

Full Network Data received from the Leader.

Only present on Thread networks.

history_report: Option<ThreadHistoryReport>

Aggregates Thread network events histories from the History Tracker.

Only present on Thread networks.

ipaddrs: Option<Vec<NetifAddress>>

IPv6 unicast address list configured on a Thread interface.

Only present on Thread Networks.

ipmaddrs: Option<Vec<Ipv6Address>>

IPv6 multicast address list configured on a Thread interface.

Only present on Thread Networks.

border_routing_prefixes: Option<Vec<BorderRoutingPrefixTable>>

Thread Border Routing discovered prefixes by Border Routing Manager on the infrastructure link.

Only present on Thread networks.

border_routing_rdnsses: Option<Vec<BorderRoutingRdnss>>

Thread Border Routing discovered Recursive DNS Server (RDNSS) by Border Routing Manager on the infrastructure link.

Only present on Thread networks.

netstat: Option<Vec<UdpSocket>>

The UDP Sockets information.

Only present on Thread networks.

eid_cache_entries: Option<Vec<EidCacheEntry>>

The EID-to-RLOC cache entries.

Only present on Thread networks.

cca_threshold: Option<i8>

CCA threshold in dBm measured at the antenna connector.

Only present on Thread networks.

csl_info: Option<CslInfo>

CSL information.

Only present on Thread networks.

buffer_info: Option<BufferInfo>

Buffer information.

Only present on Thread networks.

mle_counters: Option<MleCounters>

The counters of the MLE protocol.

Only present on Thread networks.